@@ -2,7 +2,7 @@
 #' @rdname TreeLength
 #' @export
 IWScore <- function (tree, dataset, concavity = 10L, ...) {
-  .Deprecated('TreeLength')
+  .Deprecated("TreeLength")
   TreeLength(tree, dataset, concavity)
 }
 
@@ -10,5 +10,5 @@ IWScore <- function (tree, dataset, concavity = 10L, ...) {
 #' @export
 IWTreeSearch <- function (...) {
   .Deprecated("MaximizeParsimony") # Retained as template, for now.
-  message("See also the vignette 'custom optimality criteria'")
+  message("See also the vignette \"custom optimality criteria\"")
 }
